#[non_exhaustive]pub enum ClientKind {
Agent(AgentIdentity),
}Expand description
The kind of client the Agent sees, and the details that kind reports.
The Agent requires every client to be exactly one kind, and checks that the details for that kind are present.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Agent(AgentIdentity)
A Datadog Agent process, or a process that runs alongside one.